Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog`_,
and this project adheres to `Semantic Versioning`_.

`2.0rc2`_ - 2021-09-16
----------------------

Fixed
~~~~~

* Names of preferences contained `__` in some rare cases which is forbidden.

`2.0rc1`_ - 2021-06-23
----------------------

Changed
~~~~~~~

* Add verbose name for preference section.

Fixed
~~~~~

* Preferences were evaluated before the app was ready.
* Disable LDAP sync by default to prevent loading with unexpected settings.
* Gracefully fail on missing LDAP data attributes.

`2.0b0`_ - 2021-05-21
---------------------

Changed
~~~~~~~

* Add automatic linking of groups to current school term while importing.

Removed
~~~~~~~

* Remove POSIX-specific code.

`2.0a2`_ - 2020-05-04
---------------------

Added
~~~~~

* Configurable sync strategies
* Management commands for ldap import
* Mass import of users and groups
* Sync LDAP users and groups on login

----------


.. _Keep a Changelog: https://keepachangelog.com/en/1.0.0/
.. _Semantic Versioning: https://semver.org/spec/v2.0.0.html


.. _2.0a2: https://edugit.org/AlekSIS/official/AlekSIS-App-LDAP/-/tags/2.0a2
.. _2.0b0: https://edugit.org/AlekSIS/Official/AlekSIS-App-LDAP/-/tags/2.0b0
.. _2.0rc1: https://edugit.org/AlekSIS/Official/AlekSIS-App-LDAP/-/tags/2.0rc1
.. _2.0rc2: https://edugit.org/AlekSIS/Official/AlekSIS-App-LDAP/-/tags/2.0rc2
